"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;
exports.eslintBundle = eslintBundle;
var diff = _interopRequireWildcard(require("diff"));
var _eslint = require("eslint");
var _magicString = _interopRequireDefault(require("magic-string"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }
function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }
class RollupPluginESLintBundle {
  constructor(options) {
    this.name = 'rollup-plugin-eslint-bundle';
    this.options = {
      eslintOptions: {},
      ...options
    };
    this.eslintOptions = this.options.eslintOptions || {};
    this.eslint = new _eslint.ESLint(this.eslintOptions);
  }
  regenerateSourcemap(source, modifiedSource) {
    const magicString = new _magicString.default(source);
    const changes = diff.diffChars(source, modifiedSource);
    if (changes && changes.length > 0) {
      let index = 0;
      for (const part of changes) {
        const count = part.count ?? 0;
        if (part.added) {
          magicString.prependLeft(index, part.value);
          index -= count;
        } else if (part.removed) {
          magicString.remove(index, index + count);
        }
        index += count;
      }
    }
    return {
      code: magicString.toString(),
      map: magicString.generateMap({
        hires: true
      })
    };
  }
  async lint(source, sourcemap) {
    const results = await this.eslint.lintText(source);
    const result = results[0];
    const hasWarnings = result.warningCount > 0;
    const hasErrors = result.errorCount > 0;
    if (hasWarnings || hasErrors) {
      const formatter = await this.eslint.loadFormatter(this.options.formatter);
      const formattedResults = formatter.format(results);
      if (formattedResults) {
        console.log(formattedResults);
      }
    }
    const throwOnWarning = hasWarnings && this.options.throwOnWarning;
    const throwOnError = hasErrors && this.options.throwOnError;
    if (throwOnWarning && throwOnError) {
      throw new Error('Warnings or errors were found');
    } else if (throwOnWarning) {
      throw new Error('Warnings were found');
    } else if (throwOnError) {
      throw new Error('Errors were found');
    }
    const formattedSource = result.output;
    if (!formattedSource) {
      return null;
    }
    if (!sourcemap) {
      return {
        code: formattedSource
      };
    }
    return this.regenerateSourcemap(source, formattedSource);
  }
}
function eslintBundle(options) {
  const plugin = new RollupPluginESLintBundle(options);
  return {
    name: plugin.name,
    renderChunk(source, chunkInfo, outputOptions) {
      return plugin.lint(source, outputOptions.sourcemap);
    }
  };
}
var _default = eslintBundle;
exports.default = _default;
